
.. image:: https://img.shields.io/badge/dynamic/json.svg?label=release&url=https://gitlab.com/protis/protis/-/jobs/artifacts/main/file/badges.json?job=badge&query=release_tag&color=8c4ab0&labelColor=dedede&style=for-the-badge&logo=data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNDBtbSIgaGVpZ2h0PSI0MG1tIiB2aWV3Qm94PSIwIDAgNDAgNDAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PHBhdGggZD0iTTIwLjE5MS40NjEgOC42OTggMTEuOTU0djE2LjE3NWwxMS40OTMgMTEuNDkzIDMuMjkzLTMuMjkyVjIyLjcyNmgxMy42MDNsMi42ODQtMi42ODRMMjAuMTkxLjQ2MnptLS4zOCA3Ljk0IDYuNSA2LjUtNi41IDYuNS02LjUtNi41IDYuNS02LjV6TTUuNzQ3IDE0LjkwNS42MSAyMC4wNDFsNS4xMzcgNS4xMzhWMTQuOTA0eiIgZmlsbD0iIzhjNGFiMCIvPjwvc3ZnPg==
  :target: https://gitlab.com/protis/protis/-/releases
  :alt: Release


.. image:: https://img.shields.io/gitlab/pipeline/protis/protis/main?logo=gitlab&labelColor=dedede&logoColor=ffffff&style=for-the-badge
  :target: https://gitlab.com/protis/protis/commits/main
  :alt: pipeline status


.. image:: https://img.shields.io/gitlab/coverage/protis/protis/main?logo=python&logoColor=e9d672&style=for-the-badge
 :target: https://gitlab.com/protis/protis/commits/main
 :alt: coverage report


.. image:: https://img.shields.io/badge/code%20style-black-dedede.svg?logo=python&logoColor=e9d672&style=for-the-badge
  :alt: Code style: black


.. image:: https://img.shields.io/badge/license-GPLv3-blue?color=dd7d54&logo=open-access&logoColor=dd7d54&style=for-the-badge
  :target: https://gitlab.com/protis/protis/-/blob/main/LICENCE.txt
  :alt: license



----------------------

.. image:: https://img.shields.io/pypi/v/protis?color=blue&logo=pypi&logoColor=e9d672&style=for-the-badge
  :target: https://pypi.org/project/protis/
  :alt: PyPI


.. image:: https://img.shields.io/pypi/dm/protis?logo=pypi&logoColor=e9d672&style=for-the-badge
  :alt: PyPI - Downloads


.. image:: https://img.shields.io/pypi/status/protis?logo=pypi&logoColor=e9d672&style=for-the-badge
  :alt: PyPI - Status


.. .. image:: https://img.shields.io/codeclimate/maintainability/benvial/protis?logo=code-climate&style=for-the-badge
..    :target: https://codeclimate.com/github/benvial/protis
..    :alt: Code Climate maintainability

..
.. .. image:: https://img.shields.io/badge/DOI-10.5281/zenodo.6174578-dd7d54?logo=google-scholar&logoColor=dd7d54&style=for-the-badge
..  :target: https://doi.org/10.5281/zenodo.6174578


.. ------------------------------------------------------------------------------------------
..
..
.. .. image:: https://img.shields.io/conda/vn/conda-forge/protis?logo=conda-forge&color=CD5C5C&logoColor=white&style=for-the-badge
..    :target: https://anaconda.org/conda-forge/protis
..    :alt: Conda (channel only)
..
.. .. image:: https://img.shields.io/conda/dn/conda-forge/protis?logo=conda-forge&logoColor=white&style=for-the-badge
..    :alt: Conda
..
.. .. image:: https://img.shields.io/conda/pn/conda-forge/protis?logo=conda-forge&logoColor=white&style=for-the-badge
..    :alt: Conda


----------------------------

.. inclusion-marker-badges

=============================================================
protis: Plane wave expansion method for photonic crystals
=============================================================


.. inclusion-marker-install-start

Installation
============

From pypi
---------

The package is available on `pypi <https://pypi.org/project/protis>`_.
To install, simply use:

.. code-block:: bash

  pip install protis


From sources
-------------

Sources are available on `gitlab <https://gitlab.com/protis/protis>`_. First
clone the repository and install with ``pip``:

.. code-block:: bash

  git clone https://gitlab.com/protis/protis.git
  cd protis
  pip install -e .


.. inclusion-marker-install-end


Documentation
=============

The reference documentation and examples can be found on the
`project website <https://protis.gitlab.io>`_.


License
=======


.. inclusion-marker-license-start

This software is published under the `GPLv3 license <https://www.gnu.org/licenses/gpl-3.0.en.html>`_.


.. inclusion-marker-license-end
